==> jc-1.4.0.tar.gz: soot/jimple/parser/node/PNonstaticInvoke.h <==
// public abstract class soot.jimple.parser.node.PNonstaticInvoke

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_PNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$refs	_jc_soot_jimple_parser_node_PNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$object	_jc_soot_jimple_parser_node_PNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PNonstaticInvoke$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_PNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PNonstaticInvoke$vtype _jc_soot_jimple_parser_node_PNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_PNonstaticInvoke_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/PNonstaticInvoke.h <==
// public abstract class soot.jimple.parser.node.PNonstaticInvoke

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_PNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_PNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$refs	_jc_soot_jimple_parser_node_PNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_PNonstaticInvoke$object	_jc_soot_jimple_parser_node_PNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_PNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_PNonstaticInvoke$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_PNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_PNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_PNonstaticInvoke$vtype _jc_soot_jimple_parser_node_PNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_PNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_PNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_PNonstaticInvoke_H_ */
